Skip to contents

Reset KEGG and mapping caches by deleting all cached files

Usage

reset_cache()

Value

None

Details

This function deletes all cached KEGG pathway files and mapping files stored using BiocFileCache. It prompts the user for confirmation before proceeding with the deletion.

Examples

# reset_cache()