A sample data.frame containing Differential Expression Analysis, generated with limma
Source: R/KEGGemUP-data.R
res_de_macro_IFNg_vs_naive.RdA sample data.frame containing Differential Expression Analysis, generated
with limma
Value
A sample data.frame object, extracted from the topTable function
as a result of running the limma DE workflow
Details
This data.frame object contains the results of a Differential
Expression Analysis performed (with limma) on data from the macrophage
package, contrasting the counts from naive macrophage to those associated
with IFNg.
The code to create said object can be found in the folder /inst/scripts in
the KEGGemUP package, the file is called create_deresults.R.